[−][src]Enum safe_nd::Request
RPC Request that is sent to vaults.
Variants
PutIData(IData)Put ImmutableData.
GetIData(IDataAddress)Get ImmutableData.
DeleteUnpubIData(IDataAddress)Delete unpublished ImmutableData.
PutMData(MData)Put MutableData.
GetMData(MDataAddress)Get MutableData.
Get MutableData value.
Fields of GetMDataValue
DeleteMData(MDataAddress)Delete MutableData.
GetMDataShell(MDataAddress)Get MutableData shell.
GetMDataVersion(MDataAddress)Get MutableData version.
ListMDataEntries(MDataAddress)List MutableData entries.
ListMDataKeys(MDataAddress)List MutableData keys.
ListMDataValues(MDataAddress)List MutableData values.
Set MutableData user permissions.
Fields of SetMDataUserPermissions
address: MDataAddressMutableData address.
user: PublicKeyUser to set permissions for.
permissions: MDataPermissionSetNew permissions.
version: u64Version to set.
Delete MutableData user permissions.
Fields of DelMDataUserPermissions
address: MDataAddressMutableData address.
user: PublicKeyUser to delete permissions for.
version: u64Version to delete.
ListMDataPermissions(MDataAddress)List MutableData permissions.
Get MutableData permissions for a user.
Fields of ListMDataUserPermissions
Mutate MutableData entries.
Fields of MutateMDataEntries
PutAData(AData)Put a new AppendOnlyData onto the network.
GetAData(ADataAddress)Get AppendOnlyData from the network.
Get AppendOnlyData shell at a certain point in history (data_index refers to the list of
data).
Fields of GetADataShell
address: ADataAddressAppendOnlyData address.
data_index: ADataIndexIndex of the data at which to get the shell.
DeleteAData(ADataAddress)Delete an unpublished AppendOnlyData.
This operation MUST return an error if applied to published AppendOnlyData. Only the current owner(s) can perform this action.
Get a range of entries from an AppendOnlyData object on the network.
Fields of GetADataRange
address: ADataAddressAppendOnlyData address.
range: (ADataIndex, ADataIndex)Range of entries to fetch.
For example, get 10 last entries: range: (Index::FromEnd(10), Index::FromEnd(0))
Get all entries: range: (Index::FromStart(0), Index::FromEnd(0))
Get first 5 entries: range: (Index::FromStart(0), Index::FromStart(5))
Get AppendOnlyData value.
Fields of GetADataValue
GetADataIndices(ADataAddress)Get current indices: data, owners, permissions.
GetADataLastEntry(ADataAddress)Get an entry with the current index.
List all permissions at the provided index.
Fields of GetADataPermissions
Get published permissions for a specified user(s).
Fields of GetPubADataUserPermissions
address: ADataAddressAppendOnlyData address.
permissions_index: ADataIndexPermissions index.
user: ADataUserUser to get permissions for.
Get unpublished permissions for a specified user(s).
Fields of GetUnpubADataUserPermissions
address: ADataAddressAppendOnlyData address.
permissions_index: ADataIndexPermissions index.
public_key: PublicKeyUser to get permissions for.
Get owners at the provided index.
Fields of GetADataOwners
Add a new published permissions entry.
Fields of AddPubADataPermissions
address: ADataAddressAppendOnlyData address.
permissions: ADataPubPermissionsPublished permissions.
permissions_index: u64Index to add to.
Add a new unpublished permissions entry.
Fields of AddUnpubADataPermissions
address: ADataAddressAppendOnlyData address.
permissions: ADataUnpubPermissionsUnpublished permissions.
permissions_index: u64Index to add to.
Add a new owners entry. Only the current owner(s) can perform this action.
Fields of SetADataOwner
address: ADataAddressAppendOnlyData address.
owner: ADataOwnerNew owner.
owners_index: u64Owners index.
Append sequenced AppendOnlyData at the given index.
Fields of AppendSeq
AppendUnseq(ADataAppendOperation)Append unsequenced AppendOnlyData.
Balance transfer.
Fields of TransferCoins
destination: XorNameThe destination to transfer to.
amount: CoinsThe amount in coins to transfer.
transaction_id: TransactionIdThe ID of the transaction.
Get current wallet balance.
Create a new coin balance.
Fields of CreateBalance
new_balance_owner: PublicKeyThe new owner of the balance.
amount: CoinsThe new balance amount in coins.
transaction_id: TransactionIdThe ID of the transaction.
CreateLoginPacket(LoginPacket)Create a login packet.
Create a login packet for a given user and transfer some initial coins.
Fields of CreateLoginPacketFor
new_owner: PublicKeyThe new owner of the login packet.
amount: CoinsThe new balance amount in coins.
transaction_id: TransactionIdThe ID of the transaction.
new_login_packet: LoginPacketThe new login packet.
UpdateLoginPacket(LoginPacket)Update a login packet.
GetLoginPacket(XorName)Get an encrypted login packet.
List authorised keys and version stored by Elders.
Insert an authorised key (for an app, user, etc.).
Fields of InsAuthKey
key: PublicKeyAuthorised key to be inserted
version: u64Incremented version
permissions: AppPermissionsPermissions
Delete an authorised key.
Methods
impl Request[src]
pub fn get_type(&self) -> RequestType[src]
Get the RequestType of this Request.
pub fn error_response(&self, error: Error) -> Response[src]
Creates a Response containing an error, with the Response variant corresponding to the Request variant.