[−][src]Enum safe_nd::Response
RPC responses from vaults.
Variants
Get ImmutableData.
Get MutableData.
Get MutableData shell.
Get MutableData version.
ListMDataEntries(Result<MDataEntries>)List all MutableData entries (key-value pairs).
List all MutableData keys.
ListMDataValues(Result<MDataValues>)List all MutableData values.
ListMDataUserPermissions(Result<MDataPermissionSet>)Get MutableData permissions for a user.
ListMDataPermissions(Result<BTreeMap<PublicKey, MDataPermissionSet>>)List all MutableData permissions.
GetMDataValue(Result<MDataValue>)Get MutableData value.
Get AppendOnlyData.
Get AppendOnlyData shell.
GetADataOwners(Result<ADataOwner>)Get AppendOnlyData owners.
GetADataRange(Result<ADataEntries>)Get AppendOnlyData.
Get AppendOnlyData value.
GetADataIndices(Result<ADataIndices>)Get AppendOnlyData indices.
GetADataLastEntry(Result<ADataEntry>)Get AppendOnlyData last entry.
GetADataPermissions(Result<ADataPermissions>)List all AppendOnlyData permissions at the provided index.
GetPubADataUserPermissions(Result<ADataPubPermissionSet>)Get published AppendOnlyData permissions for a user.
GetUnpubADataUserPermissions(Result<ADataUnpubPermissionSet>)Get unpublished AppendOnlyData permissions for a user..
Get coin balance.
Transaction(Result<Transaction>)Return the result of a transaction.
Get an encrypted login packet.
Get a list of authorised keys and the version of the auth keys container from Elders.
Return a success or failure status for a mutation operation.